Index: sandbox/linux/services/thread_helpers.cc |
diff --git a/sandbox/linux/services/thread_helpers.cc b/sandbox/linux/services/thread_helpers.cc |
index c1ba04a248c37c75346690dfdfaa5297dbd5c713..89648bc0aec06da77e8daa85d11358ccf8f0914f 100644 |
--- a/sandbox/linux/services/thread_helpers.cc |
+++ b/sandbox/linux/services/thread_helpers.cc |
@@ -121,12 +121,12 @@ bool ChangeThreadStateAndWatchProcFS( |
const char* message; |
if (action == ThreadAction::Start) { |
// Should start the thread before calling thread_id(). |
if (!thread->Start()) |
return false; |
} |
- const base::PlatformThreadId thread_id = thread->thread_id(); |
+ const base::PlatformThreadId thread_id = thread->GetThreadId(); |
const std::string thread_id_dir_str = |
"self/task/" + base::IntToString(thread_id) + "/"; |
@@ -121,12 +121,12 @@ bool ChangeThreadStateAndWatchProcFS( |
const char* message; |
if (action == ThreadAction::Start) { |
- // Should start the thread before calling thread_id(). |
+ // Should start the thread before calling GetThreadId(). |
if (!thread->Start()) |
return false; |